@@ -256,7 +256,7 @@ class DefaultImpl(with_metaclass(ImplMeta)):
         ):
             comparator = _type_comparators.get(conn_type._type_affinity, None)
 
-            return comparator and comparator(metadata_type, conn_type)
+            return comparator and comparator(metadata_impl, conn_type)
         else:
             return True
 
@@ -280,6 +280,9 @@ class DefaultImpl(with_metaclass(ImplMeta)):
                     inspector, table, column_info)
             return adapt
 
+    def correct_for_autogen_foreignkeys(self, conn_fks, metadata_fks):
+        pass
+
     def autogen_column_reflect(self, inspector, table, column_info):
         """A hook that is attached to the 'column_reflect' event for when
         a Table is reflected from the database during the autogenerate
@@ -334,7 +337,29 @@ def _numeric_compare(t1, t2):
             t1.scale is not None and
             t1.scale != t2.scale
         )
+
+
+def _integer_compare(t1, t2):
+    t1_small_or_big = (
+        'S' if isinstance(t1, sqltypes.SmallInteger)
+        else 'B' if isinstance(t1, sqltypes.BigInteger) else 'I'
+    )
+    t2_small_or_big = (
+        'S' if isinstance(t2, sqltypes.SmallInteger)
+        else 'B' if isinstance(t2, sqltypes.BigInteger) else 'I'
+    )
+    return t1_small_or_big != t2_small_or_big
+
+
+def _datetime_compare(t1, t2):
+    return (
+        t1.timezone != t2.timezone
+    )
+
+
 _type_comparators = {
     sqltypes.String: _string_compare,
-    sqltypes.Numeric: _numeric_compare
+    sqltypes.Numeric: _numeric_compare,
+    sqltypes.Integer: _integer_compare,
+    sqltypes.DateTime: _datetime_compare,
 }
