@@ -1397,6 +1397,12 @@ class AlterColumnOp(AlterTableOp):
          .. versionadded:: 0.7.0 'schema' can now accept a
             :class:`~sqlalchemy.sql.elements.quoted_name` construct.
 
+        :param postgresql_using: String argument which will indicate a
+         SQL expression to render within the Postgresql-specific USING clause
+         within ALTER COLUMN.
+
+         .. versionadded:: 0.8.8
+
         """
 
         alt = cls(
@@ -1637,7 +1643,7 @@ class DropColumnOp(AlterTableOp):
         return operations.invoke(op)
 
     @classmethod
-    def batch_drop_column(cls, operations, column_name):
+    def batch_drop_column(cls, operations, column_name, **kw):
         """Issue a "drop column" instruction using the current
         batch migration context.
 
@@ -1648,7 +1654,7 @@ class DropColumnOp(AlterTableOp):
         """
         op = cls(
             operations.impl.table_name, column_name,
-            schema=operations.impl.schema)
+            schema=operations.impl.schema, **kw)
         return operations.invoke(op)
 
 
