@@ -19,10 +19,25 @@ class SuiteRequirements(Requirements):
 
     @property
     def unique_constraint_reflection(self):
+        def doesnt_have_check_uq_constraints(config):
+            if not util.sqla_084:
+                return True
+            from sqlalchemy import inspect
+            insp = inspect(config.db)
+            try:
+                insp.get_unique_constraints('x')
+            except NotImplementedError:
+                return True
+            except TypeError:
+                return True
+            except Exception:
+                pass
+            return False
+
         return exclusions.skip_if(
             lambda config: not util.sqla_084,
             "SQLAlchemy 0.8.4 or greater required"
-        )
+        ) + exclusions.skip_if(doesnt_have_check_uq_constraints)
 
     @property
     def foreign_key_match(self):
@@ -42,6 +57,10 @@ class SuiteRequirements(Requirements):
     def reflects_pk_names(self):
         return exclusions.closed()
 
+    @property
+    def reflects_fk_options(self):
+        return exclusions.closed()
+
     @property
     def fail_before_sqla_079(self):
         return exclusions.fails_if(
@@ -112,3 +131,10 @@ class SuiteRequirements(Requirements):
             lambda config: not util.sqla_094,
             "SQLAlchemy 0.9.4 or greater required"
         )
+
+    @property
+    def sqlalchemy_110(self):
+        return exclusions.skip_if(
+            lambda config: not util.sqla_110,
+            "SQLAlchemy 1.1.0 or greater required"
+        )
