@@ -12,7 +12,7 @@ from alembic.testing.env import staging_env
 
 py3k = sys.version_info >= (3, )
 
-from .test_autogenerate import AutogenFixtureTest
+from ._autogen_fixtures import AutogenFixtureTest
 
 
 class NoUqReflection(object):
@@ -640,7 +640,7 @@ class PGUniqueIndexTest(AutogenerateUniqueIndexTest):
         eq_(diffs[0][1].name, "uq_name")
         eq_(len(diffs), 1)
 
-    def test_functional_ix(self):
+    def test_functional_ix_one(self):
         m1 = MetaData()
         m2 = MetaData()
 
@@ -665,6 +665,37 @@ class PGUniqueIndexTest(AutogenerateUniqueIndexTest):
             diffs = self._fixture(m1, m2)
         eq_(diffs, [])
 
+    def test_functional_ix_two(self):
+        m1 = MetaData()
+        m2 = MetaData()
+
+        t1 = Table(
+            'foo', m1,
+            Column('id', Integer, primary_key=True),
+            Column('email', String(50)),
+            Column('name', String(50))
+        )
+        Index(
+            "email_idx",
+            func.coalesce(t1.c.email, t1.c.name).desc(), unique=True)
+
+        t2 = Table(
+            'foo', m2,
+            Column('id', Integer, primary_key=True),
+            Column('email', String(50)),
+            Column('name', String(50))
+        )
+        Index(
+            "email_idx",
+            func.coalesce(t2.c.email, t2.c.name).desc(), unique=True)
+
+        with assertions.expect_warnings(
+                "Skipped unsupported reflection",
+                "autogenerate skipping functional index"
+        ):
+            diffs = self._fixture(m1, m2)
+        eq_(diffs, [])
+
 
 class MySQLUniqueIndexTest(AutogenerateUniqueIndexTest):
     reports_unnamed_constraints = True
@@ -681,6 +712,12 @@ class MySQLUniqueIndexTest(AutogenerateUniqueIndexTest):
             assert False, "unexpected success"
 
 
+class OracleUniqueIndexTest(AutogenerateUniqueIndexTest):
+    reports_unnamed_constraints = True
+    reports_unique_constraints_as_indexes = True
+    __only_on__ = "oracle"
+
+
 class NoUqReflectionIndexTest(NoUqReflection, AutogenerateUniqueIndexTest):
     reports_unique_constraints = False
     __only_on__ = 'sqlite'
@@ -798,7 +835,7 @@ class IncludeHooksTest(AutogenFixtureTest, TestBase):
                 isinstance(object_, Index) and
                 type_ == 'index' and reflected and name == 'ix1')
 
-        diffs = self._fixture(m1, m2, object_filters=[include_object])
+        diffs = self._fixture(m1, m2, object_filters=include_object)
 
         eq_(diffs[0][0], 'remove_index')
         eq_(diffs[0][1].name, 'ix2')
@@ -825,7 +862,7 @@ class IncludeHooksTest(AutogenFixtureTest, TestBase):
                 isinstance(object_, UniqueConstraint) and
                 type_ == 'unique_constraint' and reflected and name == 'uq1')
 
-        diffs = self._fixture(m1, m2, object_filters=[include_object])
+        diffs = self._fixture(m1, m2, object_filters=include_object)
 
         eq_(diffs[0][0], 'remove_constraint')
         eq_(diffs[0][1].name, 'uq2')
@@ -846,7 +883,7 @@ class IncludeHooksTest(AutogenFixtureTest, TestBase):
                 isinstance(object_, Index) and
                 type_ == 'index' and not reflected and name == 'ix1')
 
-        diffs = self._fixture(m1, m2, object_filters=[include_object])
+        diffs = self._fixture(m1, m2, object_filters=include_object)
 
         eq_(diffs[0][0], 'add_index')
         eq_(diffs[0][1].name, 'ix2')
@@ -871,7 +908,7 @@ class IncludeHooksTest(AutogenFixtureTest, TestBase):
                 type_ == 'unique_constraint' and
                 not reflected and name == 'uq1')
 
-        diffs = self._fixture(m1, m2, object_filters=[include_object])
+        diffs = self._fixture(m1, m2, object_filters=include_object)
 
         eq_(diffs[0][0], 'add_constraint')
         eq_(diffs[0][1].name, 'uq2')
@@ -899,7 +936,7 @@ class IncludeHooksTest(AutogenFixtureTest, TestBase):
                 type_ == 'index' and not reflected and name == 'ix1'
                 and isinstance(compare_to, Index))
 
-        diffs = self._fixture(m1, m2, object_filters=[include_object])
+        diffs = self._fixture(m1, m2, object_filters=include_object)
 
         eq_(diffs[0][0], 'remove_index')
         eq_(diffs[0][1].name, 'ix2')
@@ -935,7 +972,7 @@ class IncludeHooksTest(AutogenFixtureTest, TestBase):
                 not reflected and name == 'uq1'
                 and isinstance(compare_to, UniqueConstraint))
 
-        diffs = self._fixture(m1, m2, object_filters=[include_object])
+        diffs = self._fixture(m1, m2, object_filters=include_object)
 
         eq_(diffs[0][0], 'remove_constraint')
         eq_(diffs[0][1].name, 'uq2')
