@@ -191,11 +191,19 @@ unique=False, """
         )
         idx = Index('test_lower_code_idx', cast(t.c.code, String))
         op_obj = ops.CreateIndexOp.from_index(idx)
-        eq_ignore_whitespace(
-            autogenerate.render_op_text(self.autogen_context, op_obj),
-            "op.create_index('test_lower_code_idx', 'test', "
-            "[sa.text(!U'CAST(test.code AS CHAR)')], unique=False)"
-        )
+
+        if config.requirements.sqlalchemy_110.enabled:
+            eq_ignore_whitespace(
+                autogenerate.render_op_text(self.autogen_context, op_obj),
+                "op.create_index('test_lower_code_idx', 'test', "
+                "[sa.text(!U'CAST(code AS CHAR)')], unique=False)"
+            )
+        else:
+            eq_ignore_whitespace(
+                autogenerate.render_op_text(self.autogen_context, op_obj),
+                "op.create_index('test_lower_code_idx', 'test', "
+                "[sa.text(!U'CAST(test.code AS CHAR)')], unique=False)"
+            )
 
     @config.requirements.fail_before_sqla_080
     def test_render_add_index_desc(self):
@@ -882,6 +890,18 @@ unique=False, """
             "sa.Column('x', sa.Boolean(), nullable=True))"
         )
 
+    def test_render_pk_with_col_name_vs_col_key(self):
+        m = MetaData()
+        t1 = Table('t1', m, Column('x', Integer, key='y', primary_key=True))
+
+        op_obj = ops.CreateTableOp.from_table(t1)
+        eq_ignore_whitespace(
+            autogenerate.render_op_text(self.autogen_context, op_obj),
+            "op.create_table('t1',"
+            "sa.Column('x', sa.Integer(), nullable=False),"
+            "sa.PrimaryKeyConstraint('x'))"
+        )
+
     def test_render_empty_pk_vs_nonempty_pk(self):
         m = MetaData()
         t1 = Table('t1', m, Column('x', Integer))
@@ -1654,7 +1674,7 @@ class RenderNamingConventionTest(TestBase):
 
         eq_(
             autogenerate.render_python_code(uo, render_as_batch=True),
-            "### commands auto generated by Alembic - please adjust! ###\n"
+            "# ### commands auto generated by Alembic - please adjust! ###\n"
             "    op.create_table('sometable',\n"
             "    sa.Column('x', sa.Integer(), nullable=True),\n"
             "    sa.Column('y', sa.Integer(), nullable=True)\n"
@@ -1663,5 +1683,5 @@ class RenderNamingConventionTest(TestBase):
             "as batch_op:\n"
             "        batch_op.create_index("
             "'ix1', ['x', 'y'], unique=False)\n\n"
-            "    ### end Alembic commands ###"
+            "    # ### end Alembic commands ###"
         )
