@@ -5,11 +5,24 @@ from alembic.testing.fixtures import TestBase, capture_context_buffer
 from alembic.testing.env import staging_env, _sqlite_testing_config, \
     three_rev_fixture, clear_staging_env, _no_sql_testing_config, \
     _sqlite_file_db, write_script, env_file_fixture
-from alembic.testing import eq_, assert_raises_message, mock
+from alembic.testing import eq_, assert_raises_message, mock, assert_raises
 from alembic import util
+from contextlib import contextmanager
+import re
+from sqlalchemy import exc as sqla_exc
 
 
-class HistoryTest(TestBase):
+class _BufMixin(object):
+    def _buf_fixture(self):
+        # try to simulate how sys.stdout looks - we send it u''
+        # but then it's trying to encode to something.
+        buf = BytesIO()
+        wrapper = TextIOWrapper(buf, encoding='ascii', line_buffering=True)
+        wrapper.getvalue = buf.getvalue
+        return wrapper
+
+
+class HistoryTest(_BufMixin, TestBase):
 
     @classmethod
     def setup_class(cls):
@@ -34,14 +47,6 @@ class HistoryTest(TestBase):
             ]).encode("ascii", "replace").decode("ascii").strip()
         )
 
-    def _buf_fixture(self):
-        # try to simulate how sys.stdout looks - we send it u''
-        # but then it's trying to encode to something.
-        buf = BytesIO()
-        wrapper = TextIOWrapper(buf, encoding='ascii', line_buffering=True)
-        wrapper.getvalue = buf.getvalue
-        return wrapper
-
     def test_history_full(self):
         self.cfg.stdout = buf = self._buf_fixture()
         command.history(self.cfg, verbose=True)
@@ -90,6 +95,67 @@ class HistoryTest(TestBase):
         self._eq_cmd_output(buf, [self.c, self.b, self.a])
 
 
+class CurrentTest(_BufMixin, TestBase):
+
+    @classmethod
+    def setup_class(cls):
+        cls.env = env = staging_env()
+        cls.cfg = _sqlite_testing_config()
+        cls.a1 = env.generate_revision("a1", "a1")
+        cls.a2 = env.generate_revision("a2", "a2")
+        cls.a3 = env.generate_revision("a3", "a3")
+        cls.b1 = env.generate_revision("b1", "b1", head="base")
+        cls.b2 = env.generate_revision("b2", "b2", head="b1", depends_on="a2")
+        cls.b3 = env.generate_revision("b3", "b3", head="b2")
+
+    @classmethod
+    def teardown_class(cls):
+        clear_staging_env()
+
+    @contextmanager
+    def _assert_lines(self, revs):
+        self.cfg.stdout = buf = self._buf_fixture()
+
+        yield
+
+        lines = set([
+            re.match(r'(^.\w)', elem).group(1)
+            for elem in re.split(
+                "\n",
+                buf.getvalue().decode('ascii', 'replace').strip()) if elem])
+
+        eq_(lines, set(revs))
+
+    def test_no_current(self):
+        command.stamp(self.cfg, ())
+        with self._assert_lines([]):
+            command.current(self.cfg)
+
+    def test_plain_current(self):
+        command.stamp(self.cfg, ())
+        command.stamp(self.cfg, self.a3.revision)
+        with self._assert_lines(['a3']):
+            command.current(self.cfg)
+
+    def test_two_heads(self):
+        command.stamp(self.cfg, ())
+        command.stamp(self.cfg, (self.a1.revision, self.b1.revision))
+        with self._assert_lines(['a1', 'b1']):
+            command.current(self.cfg)
+
+    def test_heads_one_is_dependent(self):
+        command.stamp(self.cfg, ())
+        command.stamp(self.cfg, (self.b2.revision, ))
+        with self._assert_lines(['a2', 'b2']):
+            command.current(self.cfg)
+
+    def test_heads_upg(self):
+        command.stamp(self.cfg, (self.b2.revision, ))
+        command.upgrade(self.cfg, (self.b3.revision))
+        with self._assert_lines(['a2', 'b3']):
+            command.current(self.cfg)
+
+
 class RevisionTest(TestBase):
     def setUp(self):
         self.env = staging_env()
@@ -98,7 +164,7 @@ class RevisionTest(TestBase):
     def tearDown(self):
         clear_staging_env()
 
-    def _env_fixture(self):
+    def _env_fixture(self, version_table_pk=True):
         env_file_fixture("""
 
 from sqlalchemy import MetaData, engine_from_config
@@ -110,7 +176,10 @@ engine = engine_from_config(
 
 connection = engine.connect()
 
-context.configure(connection=connection, target_metadata=target_metadata)
+context.configure(
+    connection=connection, target_metadata=target_metadata,
+    version_table_pk=%r
+)
 
 try:
     with context.begin_transaction():
@@ -118,7 +187,7 @@ try:
 finally:
     connection.close()
 
-""")
+""" % (version_table_pk, ))
 
     def test_create_rev_plain_db_not_up_to_date(self):
         self._env_fixture()
@@ -131,7 +200,7 @@ finally:
 
     def test_create_rev_autogen_db_not_up_to_date(self):
         self._env_fixture()
-        command.revision(self.cfg)
+        assert command.revision(self.cfg)
         assert_raises_message(
             util.CommandError,
             "Target database is not up to date.",
@@ -184,12 +253,24 @@ finally:
             command.revision, self.cfg, autogenerate=True
         )
 
-    def test_err_correctly_raised_on_dupe_rows(self):
+    def test_pk_constraint_normally_prevents_dupe_rows(self):
         self._env_fixture()
         command.revision(self.cfg)
         r2 = command.revision(self.cfg)
         db = _sqlite_file_db()
         command.upgrade(self.cfg, "head")
+        assert_raises(
+            sqla_exc.IntegrityError,
+            db.execute,
+            "insert into alembic_version values ('%s')" % r2.revision
+        )
+
+    def test_err_correctly_raised_on_dupe_rows_no_pk(self):
+        self._env_fixture(version_table_pk=False)
+        command.revision(self.cfg)
+        r2 = command.revision(self.cfg)
+        db = _sqlite_file_db()
+        command.upgrade(self.cfg, "head")
         db.execute("insert into alembic_version values ('%s')" % r2.revision)
         assert_raises_message(
             util.CommandError,
@@ -369,6 +450,24 @@ class UpgradeDowngradeStampTest(TestBase):
         assert "DROP STEP 2" in buf.getvalue()
         assert "DROP STEP 1" not in buf.getvalue()
 
+    def test_none_to_head_sql(self):
+        with capture_context_buffer() as buf:
+            command.upgrade(self.cfg, "head", sql=True)
+        assert "CREATE TABLE alembic_version" in buf.getvalue()
+        assert "UPDATE alembic_version" in buf.getvalue()
+        assert "CREATE STEP 1" in buf.getvalue()
+        assert "CREATE STEP 2" in buf.getvalue()
+        assert "CREATE STEP 3" in buf.getvalue()
+
+    def test_base_to_head_sql(self):
+        with capture_context_buffer() as buf:
+            command.upgrade(self.cfg, "base:head", sql=True)
+        assert "CREATE TABLE alembic_version" in buf.getvalue()
+        assert "UPDATE alembic_version" in buf.getvalue()
+        assert "CREATE STEP 1" in buf.getvalue()
+        assert "CREATE STEP 2" in buf.getvalue()
+        assert "CREATE STEP 3" in buf.getvalue()
+
     def test_sql_stamp_from_rev(self):
         with capture_context_buffer() as buf:
             command.stamp(self.cfg, "%s:head" % self.a, sql=True)
